@@ -13,7 +13,7 @@ class BaseMatcher(ABC):
     @abstractmethod
     def match(self,
               from_list: List[str],
-              to_list: List[str]) -> pd.DataFrame:
+              to_list: List[str] = None) -> pd.DataFrame:
         """ Make sure you follow the same argument structure:
 
         Arguments:
