@@ -51,13 +51,14 @@ def cosine_similarity(from_vector: np.ndarray,
     indices, similarity = extract_best_matches(from_vector, to_vector, method="sparse")
     ```
     """
-    if top_n > len(set(to_list)):
-        top_n = len(set(to_list))
-
+    if to_list is not None:
+        if top_n > len(set(to_list)):
+            top_n = len(set(to_list))
+    
     # Slower but uses less memory
     if method == "knn":
 
-        if from_list == to_list:
+        if to_list is None:
             knn = NearestNeighbors(n_neighbors=top_n+1, n_jobs=-1, metric='cosine').fit(to_vector)
             distances, indices = knn.kneighbors(from_vector)
             distances = distances[:, 1:]
@@ -80,20 +81,20 @@ def cosine_similarity(from_vector: np.ndarray,
         # to it at least to 2 for it to work
         similarity_matrix = awesome_cossim_topn(from_vector, to_vector.T, top_n+1, min_similarity)
 
-        if from_list == to_list:
+        if to_list is None:
             similarity_matrix = similarity_matrix.tolil()
             similarity_matrix.setdiag(0.)
             similarity_matrix = similarity_matrix.tocsr()
 
-        indices = np.flip(np.argsort(similarity_matrix.toarray(), axis=-1), axis=1)[:, :top_n]
-        similarities = np.flip(np.sort(similarity_matrix.toarray(), axis=-1), axis=1)[:, :top_n]
-        similarities = [np.round(similarities[:, i], 3) for i in range(similarities.shape[1])]
+        indices = _top_n_idx_sparse(similarity_matrix, top_n)
+        similarities = _top_n_similarities_sparse(similarity_matrix, indices)
+        indices = np.array(np.nan_to_num(np.array(indices, dtype=np.float), nan=0), dtype=np.int)
 
     # Faster than knn and slower than sparse but uses more memory
     else:
         similarity_matrix = scikit_cosine_similarity(from_vector, to_vector)
 
-        if from_list == to_list:
+        if to_list is None:
             np.fill_diagonal(similarity_matrix, 0)
 
         indices = np.flip(np.argsort(similarity_matrix, axis=-1), axis=1)[:, :top_n]
@@ -101,9 +102,12 @@ def cosine_similarity(from_vector: np.ndarray,
         similarities = [np.round(similarities[:, i], 3) for i in range(similarities.shape[1])]
 
     # Convert results to df
-    columns =  (["From"] +
-                ["To" if i == 0 else f"To_{i+1}" for i in range(top_n)] +
-                ["Similarity" if i ==0 else f"Similarity_{i+1}" for i in range(top_n)]); columns
+    if to_list is None:
+        to_list = from_list.copy()
+        
+    columns = (["From"] +
+               ["To" if i == 0 else f"To_{i+1}" for i in range(top_n)] +
+               ["Similarity" if i ==0 else f"Similarity_{i+1}" for i in range(top_n)])
     matches = [[to_list[idx] for idx in indices[:, i]] for i in range(indices.shape[1])]
     matches = pd.DataFrame(np.vstack(([from_list], matches, similarities)).T, columns = columns)
 
@@ -119,3 +123,24 @@ def cosine_similarity(from_vector: np.ndarray,
             matches.loc[matches[column] < 0.001, column.replace("Similarity", "To")] = None
 
     return matches
+
+
+def _top_n_idx_sparse(matrix, n):
+    """ Return index of top n values in each row of a sparse matrix """
+    top_n_idx = []
+    for le, ri in zip(matrix.indptr[:-1], matrix.indptr[1:]):
+        n_row_pick = min(n, ri - le)
+        values = list(matrix.indices[le + np.argpartition(matrix.data[le:ri], -n_row_pick)[-n_row_pick:]])[::-1]
+        values = [values[index] if len(values) >= index + 1 else None for index in range(n)]
+        top_n_idx.append(values)
+    return np.array(top_n_idx)
+
+
+def _top_n_similarities_sparse(matrix, indices):
+    """ Return similarity scores of top n values in each row of a sparse matrix """
+    similarity_scores = []
+    for row, values in enumerate(indices):
+        scores = [round(matrix[row, value], 3) if value is not None else 0 for value in values]
+        similarity_scores.append(scores)
+    similarity_scores = np.array(similarity_scores).T
+    return similarity_scores
